# 14 "src/why3doc/doc_lexer.mll"
 

  open Format
  open Lexing
  open Why3

  let output_comments = ref true

  let newline lexbuf =
    let pos = lexbuf.lex_curr_p in
    lexbuf.lex_curr_p <-
      { pos with pos_lnum = pos.pos_lnum + 1; pos_bol = pos.pos_cnum }

  let make_table l =
    let ht = Hashtbl.create 97 in
    List.iter (fun s -> Hashtbl.add ht s ()) l;
    Hashtbl.mem ht

  let is_keyword1 = make_table [ "as"; "axiom"; "clone"; "coinductive";
    "constant"; "else"; "end"; "epsilon"; "exists"; "export"; "false";
    "forall"; "function"; "goal"; "if"; "import"; "in"; "inductive";
    "lemma"; "let"; "match"; "meta"; "namespace"; "not"; "predicate";
    "prop"; "then"; "theory"; "true"; "type"; "use"; "with";
    (* programs *) "abstract"; "any";
    "begin"; "do"; "done"; "downto"; "exception";
    "for"; "fun"; "ghost"; "loop"; "model"; "module";
    "mutable"; "private"; "raise"; "rec";
    "to"; "try"; "val"; "while"; ]

  let is_keyword2 = make_table [ "absurd"; "assert"; "assume";
    "ensures"; "check"; "invariant"; "raises"; "reads"; "requires";
    "returns"; "variant"; "writes"; ]

  let get_loc lb =
    let p = Lexing.lexeme_start_p lb in
    p.pos_fname, p.pos_lnum, p.pos_cnum - p.pos_bol

  let html_char fmt c =
    pp_print_string fmt (match c with
      | '<' -> "&lt;"
      | '>' -> "&gt;"
      | '&' -> "&amp;"
      | _ -> assert false)

  let html_escape s =
    let len = ref 0 in
    String.iter (function '<' | '>' -> len := !len + 4
      | '&' -> len := !len + 5 | _ -> incr len) s;
    let len' = !len in
    let len = String.length s in
    if len = len' then s else begin
      let t = String.create len' in
      let j = ref 0 in
      let app u =
        let l = String.length u in
        String.blit u 0 t !j l;
        j := !j + l in
      for i = 0 to len - 1 do
        match s.[i] with
        | '<' -> app "&lt;"
        | '>' -> app "&gt;"
        | '&' -> app "&amp;"
        | c -> t.[!j] <- c; incr j
      done;
      t
    end

  let current_file = ref ""

  let print_ident fmt lexbuf s =
    if is_keyword1 s then
      fprintf fmt "<span class=\"keyword1\">%s</span>" s
    else if is_keyword2 s then
      fprintf fmt "<span class=\"keyword2\">%s</span>" s
    else begin
      let (* f,l,c as *) loc = get_loc lexbuf in
      (* Format.eprintf "  IDENT %s/%d/%d@." f l c; *)
      (* is this a def point? *)
      let s = html_escape s in
      try
        let t = Doc_def.is_def loc in
        fprintf fmt "<a name=\"%s\">%s</a>" t s
      with Not_found ->
      (* is this a use point? *)
      try
        let id = Glob.locate loc in
        let fn, url, t = Doc_def.locate id in
        let url = if fn = !current_file then "" else url in
        fprintf fmt "<a href=\"%s#%s\">%s</a>" url t s
      with Not_found ->
        (* otherwise, just print it *)
        pp_print_string fmt s
    end

  type empty_line = PrevEmpty | CurrEmpty | NotEmpty


# 100 "src/why3doc/doc_lexer.ml"
let __ocaml_lex_tables = {
  Lexing.lex_base = 
   "\000\000\247\255\007\000\248\255\249\255\032\000\094\000\133\000\
    \179\000\225\000\008\001\070\001\251\255\012\000\006\000\008\000\
    \009\000\255\255\254\255\011\000\133\000\012\000\250\255\010\000\
    \033\000\011\000\003\000\018\000\183\001\249\255\025\000\250\255\
    \251\255\019\002\058\002\104\002\143\002\189\002\222\002\253\255\
    \254\255\068\000\078\000\073\000\089\000\252\255\042\000\099\000\
    \050\001\249\255\110\000\250\255\251\255\252\255\253\255\104\000\
    \104\000\255\255\254\255\108\000\071\001\252\255\008\000\253\255\
    \254\255\255\255\096\002\244\255\245\255\247\255\248\255\132\000\
    \001\000\254\255\107\000\117\000\109\000\121\000\255\255\253\255\
    \250\255\119\000\198\000\251\255\252\255\253\255\254\255\255\255\
    \191\000\252\255\254\255\155\000\118\000\120\000\158\000\153\000\
    \052\000\255\255\204\000\252\255\253\255\130\000\133\000\255\255\
    \254\255";
  Lexing.lex_backtrk = 
   "\255\255\255\255\008\000\255\255\255\255\008\000\005\000\005\000\
    \005\000\005\000\005\000\005\000\255\255\008\000\008\000\003\000\
    \002\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \005\000\255\255\255\255\255\255\255\255\255\255\006\000\255\255\
    \255\255\003\000\003\000\003\000\003\000\003\000\003\000\255\255\
    \255\255\000\000\255\255\003\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\006\000\255\255\255\255\255\255\255\255\006\000\
    \006\000\255\255\255\255\255\255\255\255\255\255\003\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\006\000\
    \003\000\255\255\011\000\009\000\255\255\255\255\255\255\255\255\
    \255\255\004\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\001\000\003\000\002\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\003\000\003\000\255\255\
    \255\255";
  Lexing.lex_default = 
   "\001\000\000\000\255\255\000\000\000\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\000\000\255\255\255\255\255\255\
    \255\255\000\000\000\000\255\255\255\255\255\255\000\000\255\255\
    \255\255\255\255\255\255\255\255\029\000\000\000\255\255\000\000\
    \000\000\255\255\255\255\255\255\255\255\255\255\255\255\000\000\
    \000\000\255\255\255\255\255\255\255\255\000\000\255\255\255\255\
    \049\000\000\000\255\255\000\000\000\000\000\000\000\000\255\255\
    \255\255\000\000\000\000\255\255\061\000\000\000\061\000\000\000\
    \000\000\000\000\067\000\000\000\000\000\000\000\000\000\255\255\
    \255\255\000\000\255\255\255\255\255\255\255\255\000\000\000\000\
    \000\000\255\255\083\000\000\000\000\000\000\000\000\000\000\000\
    \089\000\000\000\000\000\255\255\255\255\255\255\255\255\255\255\
    \096\000\000\000\099\000\000\000\000\000\255\255\255\255\000\000\
    \000\000";
  Lexing.lex_trans = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\013\000\004\000\079\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\020\000\004\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \013\000\010\000\003\000\006\000\006\000\007\000\006\000\002\000\
    \014\000\027\000\007\000\008\000\020\000\008\000\006\000\007\000\
    \015\000\017\000\016\000\018\000\019\000\021\000\016\000\026\000\
    \022\000\001\000\006\000\047\000\009\000\009\000\009\000\010\000\
    \006\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\005\000\023\000\025\000\006\000\011\000\
    \022\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\046\000\006\000\024\000\009\000\006\000\
    \042\000\006\000\006\000\007\000\006\000\044\000\045\000\045\000\
    \007\000\008\000\029\000\008\000\006\000\007\000\020\000\004\000\
    \059\000\058\000\057\000\049\000\078\000\077\000\078\000\081\000\
    \006\000\077\000\009\000\009\000\009\000\006\000\006\000\076\000\
    \093\000\043\000\094\000\076\000\091\000\020\000\007\000\094\000\
    \007\000\007\000\007\000\007\000\104\000\019\000\103\000\007\000\
    \008\000\097\000\008\000\007\000\007\000\081\000\081\000\081\000\
    \081\000\081\000\081\000\091\000\006\000\022\000\094\000\007\000\
    \000\000\009\000\009\000\009\000\007\000\007\000\000\000\000\000\
    \091\000\090\000\096\000\096\000\096\000\096\000\096\000\096\000\
    \086\000\000\000\000\000\000\000\008\000\000\000\008\000\008\000\
    \008\000\008\000\006\000\000\000\009\000\008\000\008\000\091\000\
    \008\000\008\000\008\000\007\000\022\000\000\000\000\000\092\000\
    \000\000\000\000\000\000\000\000\080\000\008\000\000\000\009\000\
    \009\000\009\000\008\000\008\000\101\000\000\000\102\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \012\000\007\000\009\000\009\000\009\000\009\000\009\000\009\000\
    \255\255\000\000\000\000\009\000\009\000\000\000\009\000\009\000\
    \009\000\008\000\022\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\095\000\000\000\009\000\000\000\009\000\009\000\009\000\
    \009\000\009\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\010\000\000\000\010\000\010\000\007\000\010\000\008\000\
    \000\000\009\000\007\000\008\000\255\255\008\000\010\000\007\000\
    \000\000\000\000\000\000\000\000\053\000\000\000\000\000\009\000\
    \022\000\085\000\010\000\084\000\009\000\009\000\009\000\010\000\
    \010\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\065\000\000\000\000\000\052\000\000\000\000\000\000\000\
    \051\000\050\000\056\000\000\000\055\000\009\000\000\000\009\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\010\000\022\000\
    \000\000\064\000\000\000\000\000\000\000\063\000\051\000\000\000\
    \051\000\000\000\000\000\000\000\000\000\000\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \000\000\000\000\000\000\063\000\010\000\063\000\009\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\000\000\000\000\062\000\000\000\011\000\000\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\032\000\000\000\000\000\000\000\000\000\087\000\000\000\
    \000\000\000\000\000\000\000\000\100\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \037\000\031\000\033\000\033\000\034\000\033\000\030\000\000\000\
    \000\000\034\000\035\000\000\000\035\000\033\000\034\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\033\000\000\000\036\000\036\000\036\000\037\000\033\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\041\000\000\000\040\000\033\000\038\000\000\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\054\000\033\000\033\000\036\000\033\000\033\000\
    \034\000\033\000\000\000\000\000\000\000\034\000\035\000\000\000\
    \035\000\033\000\034\000\000\000\000\000\000\000\000\000\255\255\
    \000\000\000\000\000\000\000\000\000\000\033\000\000\000\036\000\
    \036\000\036\000\033\000\033\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\034\000\000\000\034\000\034\000\034\000\
    \034\000\000\000\000\000\000\000\034\000\035\000\000\000\035\000\
    \034\000\034\000\072\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\033\000\045\000\000\000\034\000\000\000\036\000\036\000\
    \036\000\034\000\034\000\000\000\000\000\000\000\000\000\000\000\
    \075\000\000\000\000\000\000\000\000\000\000\000\068\000\000\000\
    \000\000\035\000\074\000\035\000\035\000\035\000\035\000\033\000\
    \000\000\036\000\035\000\035\000\000\000\035\000\035\000\035\000\
    \034\000\045\000\000\000\000\000\068\000\000\000\068\000\000\000\
    \000\000\000\000\035\000\000\000\036\000\036\000\036\000\035\000\
    \035\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \036\000\000\000\036\000\036\000\036\000\036\000\034\000\039\000\
    \036\000\036\000\036\000\069\000\036\000\036\000\036\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\035\000\045\000\
    \000\000\036\000\000\000\036\000\036\000\036\000\036\000\036\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\071\000\000\000\070\000\037\000\000\000\
    \037\000\037\000\034\000\037\000\035\000\000\000\036\000\034\000\
    \035\000\000\000\035\000\037\000\034\000\036\000\045\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\037\000\
    \000\000\036\000\036\000\036\000\037\000\037\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\036\000\000\000\036\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \000\000\000\000\000\000\037\000\045\000\000\000\000\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\037\000\000\000\036\000\000\000\038\000\000\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \073\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000";
  Lexing.lex_check = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\000\000\000\000\072\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\013\000\013\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\002\000\000\000\000\000\013\000\000\000\000\000\000\000\
    \014\000\015\000\015\000\016\000\013\000\019\000\021\000\023\000\
    \025\000\027\000\000\000\030\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\005\000\024\000\000\000\000\000\
    \026\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\042\000\000\000\005\000\000\000\006\000\
    \041\000\006\000\006\000\006\000\006\000\043\000\044\000\046\000\
    \006\000\006\000\047\000\006\000\006\000\006\000\020\000\020\000\
    \050\000\055\000\056\000\059\000\074\000\075\000\076\000\081\000\
    \006\000\077\000\006\000\006\000\006\000\006\000\006\000\075\000\
    \092\000\041\000\093\000\077\000\091\000\020\000\007\000\094\000\
    \007\000\007\000\007\000\007\000\101\000\020\000\102\000\007\000\
    \007\000\096\000\007\000\007\000\007\000\071\000\071\000\071\000\
    \071\000\071\000\071\000\091\000\006\000\006\000\094\000\007\000\
    \255\255\007\000\007\000\007\000\007\000\007\000\255\255\255\255\
    \088\000\088\000\095\000\095\000\095\000\095\000\095\000\095\000\
    \082\000\255\255\255\255\255\255\008\000\255\255\008\000\008\000\
    \008\000\008\000\006\000\255\255\006\000\008\000\008\000\088\000\
    \008\000\008\000\008\000\007\000\007\000\255\255\255\255\088\000\
    \255\255\255\255\255\255\255\255\071\000\008\000\255\255\008\000\
    \008\000\008\000\008\000\008\000\098\000\255\255\098\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \000\000\007\000\009\000\007\000\009\000\009\000\009\000\009\000\
    \062\000\255\255\255\255\009\000\009\000\255\255\009\000\009\000\
    \009\000\008\000\008\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\094\000\255\255\009\000\255\255\009\000\009\000\009\000\
    \009\000\009\000\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\010\000\255\255\010\000\010\000\010\000\010\000\008\000\
    \255\255\008\000\010\000\010\000\096\000\010\000\010\000\010\000\
    \255\255\255\255\255\255\255\255\048\000\255\255\255\255\009\000\
    \009\000\082\000\010\000\082\000\010\000\010\000\010\000\010\000\
    \010\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\060\000\255\255\255\255\048\000\255\255\255\255\255\255\
    \048\000\048\000\048\000\255\255\048\000\009\000\255\255\009\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\010\000\010\000\
    \255\255\060\000\255\255\255\255\255\255\060\000\048\000\255\255\
    \048\000\255\255\255\255\255\255\255\255\255\255\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \255\255\255\255\255\255\060\000\010\000\060\000\010\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\255\255\255\255\060\000\255\255\011\000\255\255\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\011\000\011\000\011\000\011\000\011\000\011\000\011\000\
    \011\000\028\000\255\255\255\255\255\255\255\255\082\000\255\255\
    \255\255\255\255\255\255\255\255\098\000\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\255\255\
    \255\255\028\000\028\000\255\255\028\000\028\000\028\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\028\000\255\255\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\255\255\028\000\028\000\028\000\255\255\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\028\000\028\000\028\000\028\000\028\000\028\000\
    \028\000\028\000\048\000\028\000\033\000\028\000\033\000\033\000\
    \033\000\033\000\255\255\255\255\255\255\033\000\033\000\255\255\
    \033\000\033\000\033\000\255\255\255\255\255\255\255\255\060\000\
    \255\255\255\255\255\255\255\255\255\255\033\000\255\255\033\000\
    \033\000\033\000\033\000\033\000\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\034\000\255\255\034\000\034\000\034\000\
    \034\000\255\255\255\255\255\255\034\000\034\000\255\255\034\000\
    \034\000\034\000\066\000\255\255\255\255\255\255\255\255\255\255\
    \255\255\033\000\033\000\255\255\034\000\255\255\034\000\034\000\
    \034\000\034\000\034\000\255\255\255\255\255\255\255\255\255\255\
    \066\000\255\255\255\255\255\255\255\255\255\255\066\000\255\255\
    \255\255\035\000\066\000\035\000\035\000\035\000\035\000\033\000\
    \255\255\033\000\035\000\035\000\255\255\035\000\035\000\035\000\
    \034\000\034\000\255\255\255\255\066\000\255\255\066\000\255\255\
    \255\255\255\255\035\000\255\255\035\000\035\000\035\000\035\000\
    \035\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \036\000\255\255\036\000\036\000\036\000\036\000\034\000\028\000\
    \034\000\036\000\036\000\066\000\036\000\036\000\036\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\035\000\035\000\
    \255\255\036\000\255\255\036\000\036\000\036\000\036\000\036\000\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\066\000\255\255\066\000\037\000\255\255\
    \037\000\037\000\037\000\037\000\035\000\255\255\035\000\037\000\
    \037\000\255\255\037\000\037\000\037\000\036\000\036\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\037\000\
    \255\255\037\000\037\000\037\000\037\000\037\000\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\036\000\255\255\036\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \255\255\255\255\255\255\037\000\037\000\255\255\255\255\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\037\000\255\255\037\000\255\255\038\000\255\255\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\038\000\038\000\038\000\038\000\038\000\038\000\038\000\
    \038\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \066\000\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255";
  Lexing.lex_base_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\004\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_backtrk_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_default_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_trans_code = 
   "\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\001\000\001\000\001\000\001\000\001\000\001\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\
    \000\000";
  Lexing.lex_check_code = 
   "\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\095\000\095\000\095\000\095\000\095\000\095\000\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\255\
    \255\255";
  Lexing.lex_code = 
   "\255\001\255\255\000\001\255";
}

let rec scan fmt empty lexbuf =
    __ocaml_lex_scan_rec fmt empty lexbuf 0
and __ocaml_lex_scan_rec fmt empty lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 138 "src/why3doc/doc_lexer.mll"
             s
# 522 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos (lexbuf.Lexing.lex_start_pos + 3) in
# 139 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt s;
            scan fmt NotEmpty lexbuf )
# 527 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 142 "src/why3doc/doc_lexer.mll"
          ( comment fmt false lexbuf;
            scan fmt empty lexbuf )
# 533 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 145 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "</pre>\n";
            if empty <> PrevEmpty then
              pp_print_string fmt "<div class=\"info\">";
            doc fmt false [] lexbuf;
            if empty <> PrevEmpty then pp_print_string fmt "</div>";
            pp_print_string fmt "<pre>";
            scan fmt CurrEmpty lexbuf )
# 544 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 153 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "<span class=\"comment\">(*";
            comment fmt true lexbuf;
            pp_print_string fmt "</span>";
            scan fmt NotEmpty lexbuf )
# 552 "src/why3doc/doc_lexer.ml"

  | 4 ->
# 157 "src/why3doc/doc_lexer.mll"
          ( () )
# 557 "src/why3doc/doc_lexer.ml"

  | 5 ->
let
# 158 "src/why3doc/doc_lexer.mll"
             s
# 563 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 159 "src/why3doc/doc_lexer.mll"
          ( print_ident fmt lexbuf s;
            scan fmt NotEmpty lexbuf )
# 568 "src/why3doc/doc_lexer.ml"

  | 6 ->
# 162 "src/why3doc/doc_lexer.mll"
          ( newline lexbuf;
            if empty <> PrevEmpty then pp_print_char fmt '\n';
            let e = if empty = NotEmpty then CurrEmpty else PrevEmpty in
            scan fmt e lexbuf )
# 576 "src/why3doc/doc_lexer.ml"

  | 7 ->
# 166 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt "&quot;";
            string fmt true lexbuf;
            scan fmt NotEmpty lexbuf )
# 583 "src/why3doc/doc_lexer.ml"

  | 8 ->
let
# 170 "src/why3doc/doc_lexer.mll"
         s
# 589 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 171 "src/why3doc/doc_lexer.mll"
          ( pp_print_string fmt s;
            scan fmt NotEmpty lexbuf )
# 594 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_scan_rec fmt empty lexbuf __ocaml_lex_state

and scan_embedded fmt depth lexbuf =
    __ocaml_lex_scan_embedded_rec fmt depth lexbuf 28
and __ocaml_lex_scan_embedded_rec fmt depth lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 175 "src/why3doc/doc_lexer.mll"
          ( pp_print_char fmt '[';
            scan_embedded fmt (depth + 1) lexbuf )
# 606 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 177 "src/why3doc/doc_lexer.mll"
          ( if depth > 0 then begin
              pp_print_char fmt ']';
              scan_embedded fmt (depth - 1) lexbuf
            end )
# 614 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 181 "src/why3doc/doc_lexer.mll"
          ( () )
# 619 "src/why3doc/doc_lexer.ml"

  | 3 ->
let
# 182 "src/why3doc/doc_lexer.mll"
             s
# 625 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 183 "src/why3doc/doc_lexer.mll"
          ( print_ident fmt lexbuf s;
            scan_embedded fmt depth lexbuf )
# 630 "src/why3doc/doc_lexer.ml"

  | 4 ->
# 185 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             pp_print_char fmt '\n';
             scan_embedded fmt depth lexbuf )
# 637 "src/why3doc/doc_lexer.ml"

  | 5 ->
# 188 "src/why3doc/doc_lexer.mll"
           ( pp_print_string fmt "&quot;";
             string fmt true lexbuf;
             scan_embedded fmt depth lexbuf )
# 644 "src/why3doc/doc_lexer.ml"

  | 6 ->
let
# 192 "src/why3doc/doc_lexer.mll"
         s
# 650 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 192 "src/why3doc/doc_lexer.mll"
           ( pp_print_string fmt s;
             scan_embedded fmt depth lexbuf )
# 655 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_scan_embedded_rec fmt depth lexbuf __ocaml_lex_state

and comment fmt do_output lexbuf =
    __ocaml_lex_comment_rec fmt do_output lexbuf 48
and __ocaml_lex_comment_rec fmt do_output lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 196 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "(*";
             comment fmt do_output lexbuf;
             comment fmt do_output lexbuf )
# 668 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 199 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "*)" )
# 673 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 200 "src/why3doc/doc_lexer.mll"
           ( () )
# 678 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 201 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             if do_output then pp_print_char fmt '\n';
             comment fmt do_output lexbuf )
# 685 "src/why3doc/doc_lexer.ml"

  | 4 ->
# 204 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "&quot;";
             string fmt do_output lexbuf;
             comment fmt do_output lexbuf )
# 692 "src/why3doc/doc_lexer.ml"

  | 5 ->
let
# 207 "src/why3doc/doc_lexer.mll"
               c
# 698 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 208 "src/why3doc/doc_lexer.mll"
           ( if do_output then html_char fmt c;
             comment fmt do_output lexbuf )
# 703 "src/why3doc/doc_lexer.ml"

  | 6 ->
let
# 211 "src/why3doc/doc_lexer.mll"
         s
# 709 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 211 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt s;
             comment fmt do_output lexbuf )
# 714 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_comment_rec fmt do_output lexbuf __ocaml_lex_state

and string fmt do_output lexbuf =
    __ocaml_lex_string_rec fmt do_output lexbuf 60
and __ocaml_lex_string_rec fmt do_output lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 215 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             if do_output then pp_print_char fmt '\n';
             string fmt do_output lexbuf )
# 727 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 218 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt "&quot;" )
# 732 "src/why3doc/doc_lexer.ml"

  | 2 ->
let
# 219 "src/why3doc/doc_lexer.mll"
               c
# 738 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 220 "src/why3doc/doc_lexer.mll"
           ( if do_output then html_char fmt c;
             string fmt do_output lexbuf )
# 743 "src/why3doc/doc_lexer.ml"

  | 3 ->
let
# 223 "src/why3doc/doc_lexer.mll"
         s
# 749 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_start_pos lexbuf.Lexing.lex_curr_pos in
# 223 "src/why3doc/doc_lexer.mll"
           ( if do_output then pp_print_string fmt s;
             string fmt do_output lexbuf )
# 754 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_string_rec fmt do_output lexbuf __ocaml_lex_state

and doc fmt block headings lexbuf =
    __ocaml_lex_doc_rec fmt block headings lexbuf 66
and __ocaml_lex_doc_rec fmt block headings lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 228 "src/why3doc/doc_lexer.mll"
           ( if block then pp_print_string fmt "</p>\n" )
# 765 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 229 "src/why3doc/doc_lexer.mll"
           ( () )
# 770 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 230 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             newline lexbuf;
             if block then pp_print_string fmt "</p>";
             pp_print_char fmt '\n';
             doc fmt false headings lexbuf )
# 779 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 235 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             pp_print_char fmt '\n';
             doc fmt block headings lexbuf )
# 786 "src/why3doc/doc_lexer.ml"

  | 4 ->
let
# 238 "src/why3doc/doc_lexer.mll"
                      c
# 792 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf (lexbuf.Lexing.lex_start_pos + 1) in
# 239 "src/why3doc/doc_lexer.mll"
           ( if block then pp_print_string fmt "</p>\n";
             let n = Char.code c - Char.code '0' in
             fprintf fmt "<h%d>" n;
             doc fmt true (n::headings) lexbuf )
# 799 "src/why3doc/doc_lexer.ml"

  | 5 ->
# 243 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             raw_html fmt 0 lexbuf; doc fmt true headings lexbuf )
# 805 "src/why3doc/doc_lexer.ml"

  | 6 ->
# 245 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             pp_print_char fmt '{';
             doc fmt true (0::headings) lexbuf )
# 812 "src/why3doc/doc_lexer.ml"

  | 7 ->
# 248 "src/why3doc/doc_lexer.mll"
           ( let brace r =
               if not block then pp_print_string fmt "<p>";
               pp_print_char fmt '}';
               doc fmt true r lexbuf
             in
             match headings with
              | [] -> brace headings
              | n :: r ->
                if n >= 1 then begin
                  fprintf fmt "</h%d>" n;
                  doc fmt (r <> []) r lexbuf
                end else brace r
           )
# 829 "src/why3doc/doc_lexer.ml"

  | 8 ->
# 261 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             pp_print_string fmt "<code>";
             scan_embedded fmt 0 lexbuf;
             pp_print_string fmt "</code>";
             doc fmt true headings lexbuf )
# 838 "src/why3doc/doc_lexer.ml"

  | 9 ->
# 266 "src/why3doc/doc_lexer.mll"
           ( if block then pp_print_char fmt ' ';
             doc fmt block headings lexbuf )
# 844 "src/why3doc/doc_lexer.ml"

  | 10 ->
let
# 268 "src/why3doc/doc_lexer.mll"
               c
# 850 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 269 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             html_char fmt c;
             doc fmt true headings lexbuf )
# 856 "src/why3doc/doc_lexer.ml"

  | 11 ->
let
# 272 "src/why3doc/doc_lexer.mll"
         c
# 862 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 272 "src/why3doc/doc_lexer.mll"
           ( if not block then pp_print_string fmt "<p>";
             pp_print_char fmt c;
             doc fmt true headings lexbuf )
# 868 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_doc_rec fmt block headings lexbuf __ocaml_lex_state

and raw_html fmt depth lexbuf =
    __ocaml_lex_raw_html_rec fmt depth lexbuf 82
and __ocaml_lex_raw_html_rec fmt depth lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 278 "src/why3doc/doc_lexer.mll"
           ( () )
# 879 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 279 "src/why3doc/doc_lexer.mll"
           ( newline lexbuf;
             pp_print_char fmt '\n';
             raw_html fmt depth lexbuf )
# 886 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 282 "src/why3doc/doc_lexer.mll"
           ( pp_print_char fmt '{'; raw_html fmt (succ depth) lexbuf )
# 891 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 283 "src/why3doc/doc_lexer.mll"
           ( if depth = 0 then () else
               begin
                 pp_print_char fmt '}';
                 raw_html fmt (pred depth) lexbuf
               end )
# 900 "src/why3doc/doc_lexer.ml"

  | 4 ->
let
# 288 "src/why3doc/doc_lexer.mll"
         c
# 906 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme_char lexbuf lexbuf.Lexing.lex_start_pos in
# 288 "src/why3doc/doc_lexer.mll"
           ( pp_print_char fmt c; raw_html fmt depth lexbuf )
# 910 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_raw_html_rec fmt depth lexbuf __ocaml_lex_state

and extract_header lexbuf =
  lexbuf.Lexing.lex_mem <- Array.create 2 (-1) ;   __ocaml_lex_extract_header_rec lexbuf 88
and __ocaml_lex_extract_header_rec lexbuf __ocaml_lex_state =
  match Lexing.new_engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
let
# 292 "src/why3doc/doc_lexer.mll"
                                            header
# 922 "src/why3doc/doc_lexer.ml"
= Lexing.sub_lexeme lexbuf lexbuf.Lexing.lex_mem.(0) (lexbuf.Lexing.lex_curr_pos + -1) in
# 293 "src/why3doc/doc_lexer.mll"
      ( header )
# 926 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 295 "src/why3doc/doc_lexer.mll"
      ( extract_header lexbuf )
# 931 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 297 "src/why3doc/doc_lexer.mll"
      ( skip_comment lexbuf; extract_header lexbuf )
# 936 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 299 "src/why3doc/doc_lexer.mll"
      ( "" )
# 941 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_extract_header_rec lexbuf __ocaml_lex_state

and skip_comment lexbuf =
    __ocaml_lex_skip_comment_rec lexbuf 98
and __ocaml_lex_skip_comment_rec lexbuf __ocaml_lex_state =
  match Lexing.engine __ocaml_lex_tables __ocaml_lex_state lexbuf with
      | 0 ->
# 302 "src/why3doc/doc_lexer.mll"
         ( () )
# 952 "src/why3doc/doc_lexer.ml"

  | 1 ->
# 303 "src/why3doc/doc_lexer.mll"
         ( skip_comment lexbuf; skip_comment lexbuf )
# 957 "src/why3doc/doc_lexer.ml"

  | 2 ->
# 304 "src/why3doc/doc_lexer.mll"
         ( () )
# 962 "src/why3doc/doc_lexer.ml"

  | 3 ->
# 305 "src/why3doc/doc_lexer.mll"
         ( skip_comment lexbuf )
# 967 "src/why3doc/doc_lexer.ml"

  | __ocaml_lex_state -> lexbuf.Lexing.refill_buff lexbuf; __ocaml_lex_skip_comment_rec lexbuf __ocaml_lex_state

;;

# 307 "src/why3doc/doc_lexer.mll"
 

  let do_file fmt fname =
    current_file := fname;
    (* input *)
    let cin = open_in fname in
    let lb = Lexing.from_channel cin in
    lb.Lexing.lex_curr_p <-
      { lb.Lexing.lex_curr_p with Lexing.pos_fname = fname };
    (* output *)
    pp_print_string fmt "<div class=\"why3doc\">\n<pre>";
    scan fmt PrevEmpty lb;
    pp_print_string fmt "</pre>\n</div>\n";
    close_in cin

  let extract_header fname =
    let cin = open_in fname in
    let lb = Lexing.from_channel cin in
    let h = extract_header lb in
    close_in cin;
    h


# 997 "src/why3doc/doc_lexer.ml"
